summaryrefslogtreecommitdiffstats
path: root/src/control
diff options
context:
space:
mode:
authorJan Holthuis <jan.holthuis@ruhr-uni-bochum.de>2021-05-19 13:00:57 +0200
committerJan Holthuis <jan.holthuis@ruhr-uni-bochum.de>2021-05-20 10:00:30 +0200
commit40ded22f0447ddfb7ad8248799566f31bf509917 (patch)
tree958a0f48c351ba28b0aea922aa6848d117192e68 /src/control
parent3656b98758adb24ff1f613eaf2ca83e352a9bf71 (diff)
midi: Make MidiOpCode a properly scoped enum class
Diffstat (limited to 'src/control')
-rw-r--r--src/control/controlbehavior.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/control/controlbehavior.cpp b/src/control/controlbehavior.cpp
index 406b1eeb58..743c4cf400 100644
--- a/src/control/controlbehavior.cpp
+++ b/src/control/controlbehavior.cpp
@@ -299,15 +299,15 @@ ControlPushButtonBehavior::ControlPushButtonBehavior(ButtonMode buttonMode,
void ControlPushButtonBehavior::setValueFromMidi(
MidiOpCode o, double dParam, ControlDoublePrivate* pControl) {
// Calculate pressed State of the midi Button
// Some controller like the RMX2 are sending always MIDI_NOTE_ON
// with a changed dParam 127 for pressed an 0 for released.
// Other controller like the VMS4 are using MIDI_NOTE_ON
// And MIDI_NOTE_OFF and a velocity value like a piano keyboard
bool pressed = true;
- if (o == MIDI_NOTE_OFF || dParam == 0) {
- // MIDI_NOTE_ON + 0 should be interpreted a released according to
+ if (o == MidiOpCode::NoteOff || dParam == 0) {
+ // MidiOpCode::NoteOn + 0 should be interpreted a released according to
// http://de.wikipedia.org/wiki/Musical_Instrument_Digital_Interface
// looking for MIDI_NOTE_ON doesn't seem to work...
pressed = false;
}
@@ -299,15 +299,15 @@ ControlPushButtonBehavior::ControlPushButtonBehavior(ButtonMode buttonMode,
MidiOpCode o, double dParam, ControlDoublePrivate* pControl) {
// Calculate pressed State of the midi Button
- // Some controller like the RMX2 are sending always MIDI_NOTE_ON
+ // Some controller like the RMX2 are sending always MidiOpCode::NoteOn
// with a changed dParam 127 for pressed an 0 for released.
@@ -299,15 +299,15 @@ ControlPushButtonBehavior::ControlPushButtonBehavior(ButtonMode buttonMode,
// with a changed dParam 127 for pressed an 0 for released.
- // Other controller like the VMS4 are using MIDI_NOTE_ON
- // And MIDI_NOTE_OFF and a velocity value like a piano keyboard
+ // Other controller like the VMS4 are using MidiOpCode::NoteOn
+ // And MidiOpCode::NoteOff and a velocity value like a piano keyboard
bool pressed = true;
@@ -299,15 +299,15 @@ ControlPushButtonBehavior::ControlPushButtonBehavior(ButtonMode buttonMode,
// http://de.wikipedia.org/wiki/Musical_Instrument_Digital_Interface
- // looking for MIDI_NOTE_ON doesn't seem to work...
+ // looking for MidiOpCode::NoteOn doesn't seem to work...
pressed = false;
}